# update-repo

Update git repo: clone if the repo does not exist; pull if the repo already exist.

### Installation

```pip install update-repo``` (```!pip install update-repo``` in jupyter notebook)

### Usage

```
from upate_repo import update_repo
update_repo(repo_name)
```
